pub struct ShellOptionDef { /* private fields */ }Expand description
Defines an option.
Implementations
Sourceimpl ShellOptionDef
impl ShellOptionDef
Sourcepub fn get(&self, options: &RuntimeOptions) -> bool
pub fn get(&self, options: &RuntimeOptions) -> bool
Retrieves the current value of this option from the given runtime options.
Arguments
options- The runtime options to retrieve the value from.
Sourcepub fn set(&self, options: &mut RuntimeOptions, value: bool)
pub fn set(&self, options: &mut RuntimeOptions, value: bool)
Sets the value of this option in the given runtime options.
Arguments
options- The runtime options to modify.value- The new value to set for the option.