OpenFile

Enum OpenFile 

pub enum OpenFile {
    Stdin(Stdin),
    Stdout(Stdout),
    Stderr(Stderr),
    File(File),
    PipeReader(PipeReader),
    PipeWriter(PipeWriter),
}
Represents a file open in a shell context.

Variants



Stdin(Stdin)

The original standard input this process was started with.



Stdout(Stdout)

The original standard output this process was started with.



Stderr(Stderr)

The original standard error this process was started with.



File(File)

A file open for reading or writing.



PipeReader(PipeReader)

A read end of a pipe.



PipeWriter(PipeWriter)

A write end of a pipe.

Implementations

Source

impl OpenFile

pub fn try_clone(&self) -> Result<Self, Error>

Tries to duplicate the open file.