Module results

Module results 

Encapsulation of execution results.

Structs

ExecutionResult
Represents the result of executing a command or similar item.
StreamingOutput
A chunk of output from streaming execution

Enums

ExecutionControlFlow
Represents a control flow transition to apply.
ExecutionExitCode
Represents an exit code from execution.
ExecutionSpawnResult
Represents the result of spawning an execution; captures both execution that immediately returns as well as execution that starts a process asynchronously.
ExecutionWaitResult
Represents the result of waiting for an execution to complete.
OutputStreamType
Identifies the output stream