pub enum ExecutionSpawnResult {
Completed(ExecutionResult),
StartedProcess(ChildProcess),
}Expand description
Represents the result of spawning an execution; captures both execution that immediately returns as well as execution that starts a process asynchronously.
Variants
Completed(ExecutionResult)
Indicates that the execution completed.
StartedProcess(ChildProcess)
Indicates that a process was started and had not yet completed.
Implementations
Sourceimpl ExecutionSpawnResult
impl ExecutionSpawnResult
Sourcepub async fn wait(
self,
no_wait: bool,
cancellation_token: Option<&CancellationToken>,
) -> Result<ExecutionWaitResult, Error>
pub async fn wait( self, no_wait: bool, cancellation_token: Option<&CancellationToken>, ) -> Result<ExecutionWaitResult, Error>
Waits for the command to complete.
Arguments
no_wait- If true, do not wait for the command to complete; return immediately.cancellation_token- Optional token to cancel the wait operation.