pub struct ExecutionResult {
pub next_control_flow: ExecutionControlFlow,
pub exit_code: ExecutionExitCode,
}Expand description
Represents the result of executing a command or similar item.
Fields
next_control_flow: ExecutionControlFlowThe control flow transition to apply after execution.
exit_code: ExecutionExitCodeThe exit code resulting from execution.
Implementations
Sourceimpl ExecutionResult
impl ExecutionResult
Sourcepub fn new(exit_code: u8) -> Self
pub fn new(exit_code: u8) -> Self
Returns a new ExecutionResult with the given exit code.
Arguments
exit_code- The exit code of the command.
Sourcepub const fn general_error() -> Self
pub const fn general_error() -> Self
Returns a new ExecutionResult with a general error exit code.
Sourcepub const fn is_success(&self) -> bool
pub const fn is_success(&self) -> bool
Returns whether the command was successful.
Sourcepub const fn is_normal_flow(&self) -> bool
pub const fn is_normal_flow(&self) -> bool
Returns whether the execution result indicates normal control flow.
Returns false if there is any control flow transition requested.
Sourcepub const fn is_break(&self) -> bool
pub const fn is_break(&self) -> bool
Returns whether the execution result indicates a loop break.
Sourcepub const fn is_continue(&self) -> bool
pub const fn is_continue(&self) -> bool
Returns whether the execution result indicates a loop continue.
Sourcepub const fn is_return_or_exit(&self) -> bool
pub const fn is_return_or_exit(&self) -> bool
Returns whether the execution result indicates an early return
from a function or script, or an exit from the shell. Returns false
otherwise, including loop breaks or continues.
Sourcepub fn is_cancelled(&self) -> bool
pub fn is_cancelled(&self) -> bool
Returns whether the execution was cancelled (exit code 130).