Module interactive

Module interactive 

Library implementing interactive command input and completion for the brush shell.

Structs

BasicShell
Represents a basic shell capable of interactive usage, with primitive support for completion and test-focused automation via pexpect and similar technologies.
InteractivePrompt
Represents an interactive prompt.
MinimalShell
Represents a minimal shell capable of taking commands from standard input and reporting results to standard output and standard error streams.
Options
Options for creating an interactive shell.
ReedlineShell
Represents an interactive shell capable of taking commands from standard input and reporting results to standard output and standard error streams.

Enums

InteractiveExecutionResult
Result of an interactive execution.
ReadResult
Result of a read operation.
ShellError
Represents an error encountered while running or otherwise managing an interactive shell.

Traits

InteractiveShell
Represents a shell capable of taking commands from standard input.