pub enum TokenizerError {
Show 13 variants
UnterminatedEscapeSequence,
UnterminatedSingleQuote(SourcePosition),
UnterminatedAnsiCQuote(SourcePosition),
UnterminatedDoubleQuote(SourcePosition),
UnterminatedBackquote(SourcePosition),
UnterminatedExtendedGlob(SourcePosition),
UnterminatedVariable,
UnterminatedCommandSubstitution,
FailedDecoding,
MissingHereTagForDocumentBody,
MissingHereTag(String),
UnterminatedHereDocuments(String, String),
ReadError(Error),
}Expand description
Represents an error that occurred during tokenization.
Variants
UnterminatedEscapeSequence
An unterminated escape sequence was encountered at the end of the input stream.
UnterminatedSingleQuote(SourcePosition)
An unterminated single-quoted substring was encountered at the end of the input stream.
UnterminatedAnsiCQuote(SourcePosition)
An unterminated ANSI C-quoted substring was encountered at the end of the input stream.
UnterminatedDoubleQuote(SourcePosition)
An unterminated double-quoted substring was encountered at the end of the input stream.
UnterminatedBackquote(SourcePosition)
An unterminated back-quoted substring was encountered at the end of the input stream.
UnterminatedExtendedGlob(SourcePosition)
An unterminated extended glob (extglob) pattern was encountered at the end of the input stream.
UnterminatedVariable
An unterminated variable expression was encountered at the end of the input stream.
UnterminatedCommandSubstitution
An unterminated command substitiion was encountered at the end of the input stream.
FailedDecoding
An error occurred decoding UTF-8 characters in the input stream.
MissingHereTagForDocumentBody
An I/O here tag was missing.
MissingHereTag(String)
The indicated I/O here tag was missing.
UnterminatedHereDocuments(String, String)
An unterminated here document sequence was encountered at the end of the input stream.
ReadError(Error)
An I/O error occurred while reading from the input stream.
Implementations
Sourceimpl TokenizerError
impl TokenizerError
Sourcepub const fn is_incomplete(&self) -> bool
pub const fn is_incomplete(&self) -> bool
Returns true if the error represents an error that could possibly be due to an incomplete input stream.