Encapsulation of execution results.
Structs
- Execution
Result - Represents the result of executing a command or similar item.
- Streaming
Output - A chunk of output from streaming execution
Enums
- Execution
Control Flow - Represents a control flow transition to apply.
- Execution
Exit Code - Represents an exit code from execution.
- Execution
Spawn Result - Represents the result of spawning an execution; captures both execution that immediately returns as well as execution that starts a process asynchronously.
- Execution
Wait Result - Represents the result of waiting for an execution to complete.
- Output
Stream Type - Identifies the output stream