Library implementing interactive command input and completion for the brush shell.
Structs
- Basic
Shell - Represents a basic shell capable of interactive usage, with primitive support for completion and test-focused automation via pexpect and similar technologies.
- Interactive
Prompt - Represents an interactive prompt.
- Minimal
Shell - Represents a minimal shell capable of taking commands from standard input and reporting results to standard output and standard error streams.
- Options
- Options for creating an interactive shell.
- Reedline
Shell - Represents an interactive shell capable of taking commands from standard input and reporting results to standard output and standard error streams.
Enums
- Interactive
Execution Result - Result of an interactive execution.
- Read
Result - Result of a read operation.
- Shell
Error - Represents an error encountered while running or otherwise managing an interactive shell.
Traits
- Interactive
Shell - Represents a shell capable of taking commands from standard input.