macro_rules! minus_or_plus_flag_arg {
($struct_name:ident, $flag_char:literal, $desc:literal) => { ... };
}Expand description
Macro to define a struct that represents a shell built-in flag argument that can be enabled or disabled by specifying an option with a leading ‘+’ or ‘-’ character.
Arguments
$struct_name- The identifier to be used for the struct to define.$flag_char- The character to use as the flag.$desc- The string description of the flag.